This is a simple Repo

[![Tests](https://github.com/s4sarath/mycalc2/workflows/Tests/badge.svg)](https://github.com/s4sarath/mycalc2/actions?workflow=Tests)
[![codecov](https://codecov.io/gh/s4sarath/mycalc2/branch/main/graph/badge.svg)](https://codecov.io/gh/s4sarath/mycalc2)
